pub struct If { /* private fields */ }Expand description
Alternation. Takes a church boolean and two values, and returns the first if the boolean is true, otherwise the second.
λp.λa.λb.pabTrait Implementations
impl Copy for If
impl Eq for If
Sourceimpl Ord for If
impl Ord for If
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for If
impl PartialOrd for If
impl StructuralPartialEq for If