pub struct Curry { /* private fields */ }Expand description
Takes a function that takes two arguments and the first argument to said function,
and returns a function that takes the second argument and runs the function with both.
See Curried.
λf.λx.(λy.fxy)Trait Implementations
impl Copy for Curry
impl Eq for Curry
Sourceimpl Ord for Curry
impl Ord for Curry
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Curry
impl PartialOrd for Curry
impl StructuralPartialEq for Curry